@@ -1,34 +1,29 @@
 import json
 import os
 from abc import ABC
-from typing import List, Dict, Mapping, Tuple, Optional, TypeVar, Union, Callable, Iterable, Sequence, Any
+from typing import List, Dict, Mapping, Tuple, Optional, TypeVar, Union, Sequence, Any
 
 import sfu_data_io.helpers as io
+import sfu_ml_lib.base.metrics as metric_helpers
 import tensorflow as tf
-from tensorflow import Tensor, TensorSpec, RaggedTensorSpec, SparseTensorSpec
+from sfu_ml_lib.base.dataset import TensorTuple
+from sfu_ml_lib.base.metrics import MetricKeyType, NumericType
+from sfu_ml_lib.metrics.aggregator import KerasMetric
+from tensorflow import Tensor
+from tensorflow.data import Dataset
 from tensorflow.keras import Model
 from tensorflow.keras.callbacks import Callback
 from tensorflow.keras.losses import Loss
 from tensorflow.keras.metrics import Metric
 from tensorflow.keras.optimizers import Optimizer
 
-import sfu_ml_lib.base.metrics as metric_helpers
-from sfu_ml_lib.base.dataset import DatasetType, TensorTuple
-from sfu_ml_lib.base.metrics import MetricKeyType, NumericType
-from sfu_ml_lib.metrics.aggregator import KerasMetric
-
 
 T = TypeVar('T')
 W = TypeVar('W')
 Z = TypeVar('Z')
-BatchFunction = Callable[[], DatasetType]
-Specification = Union[SparseTensorSpec, RaggedTensorSpec, TensorSpec]
-Schema = Union[Specification, Iterable['Schema']]  # type: ignore
 
 
 class KerasModel(Model, ABC):
-    input_schema: Schema
-
     @classmethod
     def deconstruct_inputs(cls, features: T, targets: W, weights: Optional[Z] = None) -> Tuple[T, W, Optional[Z]]:
         """
@@ -70,14 +65,6 @@ class KerasModel(Model, ABC):
 
         return metric_map
 
-    def create_tf_dataset(self, batch_generator: BatchFunction, queue_size: int = -1) -> tf.data.Dataset:
-        batches = batch_generator()
-
-        if not isinstance(batches, tf.data.Dataset):
-            batches = tf.data.Dataset.from_generator(batch_generator, output_signature=self.input_schema)
-
-        return batches.prefetch(queue_size)
-
     def train_batch(
             self,
             features: T,
@@ -127,7 +114,7 @@ class KerasModel(Model, ABC):
     def test_batch(self, features: T) -> TensorTuple:
         return self(features, training=False)
 
-    def test_dataset(self, dataset: tf.data.Dataset, metrics: Sequence[Metric]) -> Mapping[str, Tensor]:
+    def test_dataset(self, dataset: Dataset, metrics: Sequence[Metric]) -> Mapping[str, Tensor]:
         for metric in metrics:
             metric.reset_state()
 
@@ -145,10 +132,10 @@ class KerasModel(Model, ABC):
 
     def fit_dataset(
             self,
-            train_batches: BatchFunction,
+            train_batches: Dataset,
             max_num_epochs: int = 1,
-            validation_batches: Optional[BatchFunction] = None,
-            test_batches: Optional[BatchFunction] = None,
+            validation_batches: Optional[Dataset] = None,
+            test_batches: Optional[Dataset] = None,
             callbacks: Optional[List[Callback]] = None,
     ) -> None:
         """
